"""
Analysis Domain.

Responsible for:
- Orchestrating system analysis workflows
- Executing diagnostic commands
- Collecting and formatting analysis results
"""
from .service import AnalysisService

__all__ = ["AnalysisService"]
